---
title: '[릴리즈노트] 2023-12-27 업데이트'
category: 업데이트
tags:
  - 관리자콘솔
  - 업데이트
searchTags:
  - 정산통합조회
  - 핵토파이낸셜 정산내역
  - 릴리즈노트
datetime: 2024-03-18T10:02:37.923Z
---

<Callout title="2023년 12월 27일 관리자콘솔 업데이트 소식을 안내드립니다." />



### **주요 업데이트 사항**

<Tag text="정산통합조회 서비스" />

✔️ **핵토파이낸셜의 정산내역을 확인할 수 있습니다.**

이번 업데이트를 통해 헥토파이낸셜을 포함한 11개 PG사와 간편결제사의 정산 내역을 조회할 수 있습니다. 관리자콘솔 메뉴 \[결제사 정산] - \[통합 내역 조회]에서 정산 내역을 조회할 수 있으며, 헥토파이낸셜의 경우 8월 1일 결제건부터 조회가 가능하오니 이용에 참고하시기 바랍니다.

📍 정산 통합 조회 서비스의 기능이 궁금하다면 [→ 서비스 소개 보기](https://guide.portone.io/a89f61e5-4545-41ae-9b72-14f506adcac6)

📍 이용 중인 결제대행사(PG사)도 정산 내역 조회가 가능한지 궁금하다면 [→ 지원 결제대행사(PG)사 확인하기](https://guide.portone.io/a89f61e5-4545-41ae-9b72-14f506adcac6)

📍 정산 통합 조회 서비스의 이용 방법이 궁금하다면 [→ 이용 방법 보기](https://guide.portone.io/92af7604-5813-48fa-a186-82e8e7356a3e)

### 기타 수정사항

<Tag text="결제서비스 V1" />

✔️ **KG이니시스 결제 시 결제 통화 위/변조 검사가 추가되었습니다**.

PC 환경에서 KG이니시스의 승인 요청시 결제  통화 및 결제 금액 위/변조 검사를 진행합니다.

#### **[\[관리자콘솔 릴리즈노트\] 2023-12-27 업데이트 보러가기↗](https://developers.portone.io/release-notes/console/2023-12-27?v=v2)**
